@@ -4,5 +4,4 @@ Package root.
 
 
 # Directly import submodules
-from . import mhc
-from . import tcr
+from . import aa, junction, mhc, tcr
